@@ -2,7 +2,7 @@ import logging
 
 from django.forms import model_to_dict
 
-from isc_common import setAttr, delAttr, getAttr
+from isc_common import setAttr, delAttr
 from isc_common.auth.managers.base_user_manager import BaseUserManager
 from isc_common.auth.models.usergroup import UserGroup
 from isc_common.bit import IsBitOn
@@ -26,6 +26,7 @@ class UserManager(BaseUserManager):
             "email": record.email,
             "middle_name": record.middle_name,
             "short_name": record.get_short_name,
+            "short_name1": record.get_short_name1,
             "password": record.password,
             "last_login": record.last_login,
             "lastmodified": record.lastmodified,
@@ -36,13 +37,13 @@ class UserManager(BaseUserManager):
         }
         return res
 
-    def updateFromRequest(self, request, printRequest=False):
+    def updateFromRequest(self, request):
         request = DSRequest(request=request)
         data = request.get_data()
         delAttr(data, 'usergroup')
         oldValues = request.get_oldValues()
 
-        _oldValues = getAttr(oldValues, 'data')
+        _oldValues = oldValues.get( 'data')
         if not _oldValues:
             _oldValues = oldValues
 
@@ -52,6 +53,7 @@ class UserManager(BaseUserManager):
 
         user_id = request.get_id()
 
+        delAttr(data, 'short_name1')
         delAttr(data, 'status')
         delAttr(data, 'timer')
         delAttr(data, 'timer4Close')
@@ -62,7 +64,7 @@ class UserManager(BaseUserManager):
 
         super().filter(id=user_id).update(**data)
 
-        if data.get('password', None) != getAttr(_oldValues, 'password'):
+        if data.get('password', None) != _oldValues.get( 'password'):
             user = self.model.objects.get(pk=user_id)
             user.set_password(data.get('password', None))
             user.save()
@@ -72,7 +74,7 @@ class UserManager(BaseUserManager):
 
         return data
 
-    def createFromRequest(self, request, printRequest=False):
+    def createFromRequest(self, request):
         request = DSRequest(request=request)
         data = request.get_data(excluded_keys=['id'])
         usergroup_id = data.get('usergroup_id')
@@ -87,7 +89,9 @@ class UserManager(BaseUserManager):
         if isinstance(usergroup_id, list):
             for group in usergroup_id:
                 user.usergroup.add(group)
-        return self.clone_data(model_to_dict(user))
+        res = model_to_dict(user)
+        setAttr(res, 'props', res.get('props')._value)
+        return self.clone_data(res)
 
     def _create_user(self, usergroup, username, email, password, **extra_fields):
         """
