@@ -1,7 +1,10 @@
 import json
+import logging
 
 from isc_common.http.RPCRequest import RPCRequest
 
+logger = logging.getLogger(__name__)
+
 
 class RequestData:
     def __init__(self, _dict=None, request=None):
@@ -37,17 +40,34 @@ class RequestData:
 
 
 class DSRequest(RPCRequest):
-    startRow = None
-    endRow = None
     alive_only = None
-    enabledAll = None
+    tag = None
+    begdate = None
     dataPageSize = 75
     drawAheadRatio = 1.2
+    enabledAll = None
+    enddate = None
+    endRow = None
+    startRow = None
     visibleMode = 'none'
 
     def __init__(self, request):
+        from isc_common.auth.models.user import User
+
         self.username = request.session._session.get('username')
         self.user_id = request.session._session.get('user_id')
+
+        try:
+            if self.user_id == None and request.GET.get('ws_channel') != None:
+                self.user_id = User.objects.get(username=request.GET.get('ws_channel').split('_')[1]).id
+            if self.user_id != None:
+                self.user = User.objects.get(id=self.user_id)
+            else:
+                self.user = None
+        except User.DoesNotExist:
+            self.user = None
+        self.is_admin = request.session._session.get('is_admin')
+        self.is_develop = request.session._session.get('is_develop')
         self.ws_channel = request.session._session.get('ws_channel')
         self.ws_port = request.session._session.get('ws_port')
         self.host = request.session._session.get('host')
@@ -56,6 +76,7 @@ class DSRequest(RPCRequest):
             try:
                 bodyStr = request.body.decode("utf-8")
                 self.json = json.loads(bodyStr)
+
             except:
                 self.json = None
 
@@ -75,6 +96,14 @@ class DSRequest(RPCRequest):
             res = dict((key, value) for (key, value) in res.items() if not key.startswith('_') and key not in excluded_keys)
         return res
 
+    def get_criteria(self, excluded_keys=['grid']):
+        data = self.get_data(excluded_keys=excluded_keys)
+        criteria = data.get('criteria')
+        if isinstance(criteria, list):
+            return criteria
+        else:
+            return []
+
     def get_data_array(self, excluded_keys=['grid']):
         res = None
         if isinstance(self.json, dict):
@@ -103,6 +132,9 @@ class DSRequest(RPCRequest):
     def get_id(self):
         return self.get_data().get('id', self.get_oldValues().get('id'))
 
+    def get_operationtype(self):
+        return self.json.get('operationType')
+
     def get_username(self):
         return self.get_data().get('username')
 
