@@ -762,7 +762,7 @@ class CommonManager(Manager):
             field = field[0]
 
         if field:
-            if field == None:
+            if field.null:
                 setAttr(_data, 'id', None)
                 res = _data
             else:
