@@ -22,10 +22,6 @@ class AuditQuerySet(CommonQuerySet):
 
         return res
 
-    # def update(self, **kwargs):
-    #     res = super().update(**kwargs)
-    #     return res
-
     def hard_delete(self):
         res = super().delete()
         return res
@@ -57,6 +53,13 @@ class AuditManager(CommonManager):
         return self.get_queryset().soft_restore()
 
 
+class Manager(CommonManager):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+    def get_queryset(self):
+        return AuditQuerySet(model=self.model)
+
 class AuditModel(Model):
     id = BigAutoField(primary_key=True, verbose_name="Идентификатор")
     deleted_at = DateTimeField(verbose_name="Дата мягкого удаления", null=True, blank=True, db_index=True)
